@@ -97,7 +97,7 @@ def keycloak_auth_header(config: SimpleNamespace) -> dict:
     }
 
 
-def keycloak_get_request(config: SimpleNamespace, path: str, params: dict = None) -> dict:
+def keycloak_get_request(config: SimpleNamespace, path: str, params: Optional[dict] = None) -> dict:
     response = requests.get(f"{config.admin_url}/{path}", headers=keycloak_auth_header(config), params=params)
     assert response.status_code == 200, response.text
     return response.json()
